@@ -14,6 +14,7 @@ Widget factories used to edit data items
 There is one widget type for each data item type.
 Example: ChoiceWidget <--> ChoiceItem, ImageChoiceItem
 """
+
 import collections.abc
 import datetime
 import os
@@ -53,6 +54,7 @@ from guidata.configtools import get_icon, get_image_file_path, get_image_layout
 from guidata.dataset.datatypes import DataItemVariable
 from guidata.qthelpers import get_std_icon, text_to_qcolor
 from guidata.utils import restore_dataset, update_dataset
+from guidata.utils.misc import convert_date_format
 from guidata.widgets.arrayeditor import ArrayEditor
 
 # ========================== <!> IMPORTANT <!> =================================
@@ -465,6 +467,10 @@ class DateWidget(AbstractDataSetWidget):
         self.dateedit = self.group = QDateEdit()
         self.dateedit.setToolTip(item.get_help())
         self.dateedit.dateTimeChanged.connect(self.date_changed)
+        fmt = self.item.get_prop("display", "format", None)
+        if fmt:
+            qt_fmt = convert_date_format(fmt)
+            self.dateedit.setDisplayFormat(qt_fmt)
 
     def date_changed(self, value):
         """Date changed"""
@@ -515,6 +521,10 @@ class DateTimeWidget(AbstractDataSetWidget):
         self.dateedit.dateTimeChanged.connect(  # type:ignore
             lambda value: self.notify_value_change()
         )
+        fmt = self.item.get_prop("display", "format", None)
+        if fmt:
+            qt_fmt = convert_date_format(fmt)
+            self.dateedit.setDisplayFormat(qt_fmt)
 
     def date_changed(self, value):
         """Date changed"""
