@@ -5,7 +5,13 @@
 # (see spyder/__init__.py for details)
 
 """
-NumPy Array Editor Dialog based on Qt
+guidata.widgets.arrayeditor
+===========================
+
+This package provides a NumPy Array Editor Dialog based on Qt.
+
+.. autoclass:: ArrayEditor
+
 """
 
 # pylint: disable=C0103
@@ -17,14 +23,24 @@ NumPy Array Editor Dialog based on Qt
 import io
 
 import numpy as np
-
+from guidata.config import CONF, _
 from guidata.configtools import get_font, get_icon
 from guidata.qthelpers import (
     add_actions,
     create_action,
     keybinding,
+    win32_fix_title_bar_background,
 )
-from guidata.config import CONF, _
+from qtpy.QtCore import (
+    QAbstractTableModel,
+    QItemSelection,
+    QItemSelectionRange,
+    QLocale,
+    QModelIndex,
+    Qt,
+    Slot,
+)
+from qtpy.QtGui import QColor, QCursor, QDoubleValidator, QKeySequence
 from qtpy.QtWidgets import (
     QAbstractItemDelegate,
     QApplication,
@@ -40,27 +56,12 @@ from qtpy.QtWidgets import (
     QMenu,
     QMessageBox,
     QPushButton,
+    QShortcut,
     QSpinBox,
     QStackedWidget,
     QTableView,
     QVBoxLayout,
     QWidget,
-    QShortcut,
-)
-from qtpy.QtCore import (
-    QAbstractTableModel,
-    QLocale,
-    QModelIndex,
-    QItemSelection,
-    QItemSelectionRange,
-    Qt,
-    Slot,
-)
-from qtpy.QtGui import (
-    QColor,
-    QCursor,
-    QDoubleValidator,
-    QKeySequence,
 )
 
 # Note: string and unicode data types will be formatted with '%s' (see below)
@@ -680,6 +681,7 @@ class ArrayEditor(QDialog):
 
     def __init__(self, parent=None):
         QDialog.__init__(self, parent)
+        win32_fix_title_bar_background(self)
 
         # Destroying the C++ object right after closing the dialog box,
         # otherwise it may be garbage-collected in another QThread
@@ -705,7 +707,7 @@ class ArrayEditor(QDialog):
         return False if data is not supported, True otherwise
         """
         self.data = data
-        self.data.flags.writeable = True
+        readonly = readonly or not self.data.flags.writeable
         is_record_array = data.dtype.names is not None
         is_masked_array = isinstance(data, np.ma.MaskedArray)
 
@@ -948,7 +950,7 @@ def launch_arrayeditor(data, title="", xlabels=None, ylabels=None):
     """Helper routine to launch an arrayeditor and return its result"""
     dlg = ArrayEditor()
     assert dlg.setup_and_check(data, title, xlabels=xlabels, ylabels=ylabels)
-    dlg.exec_()
+    dlg.exec()
     # dlg.accept()  # trigger slot connected to OK button
     return dlg.get_value()
 
